==> heuristicsmineR_0.2.1.tar.gz: heuristicsmineR/R/datasets.R <==
#' @name L_heur_1
#' @title Heuristics miner example log #1
#' @description Artifical eventlog for illustrating Heuristics Miner published as supplementary material to the book
#'  `Process Mining: Discovery, Conformance and Enhancement of Business Processes`.
#' @docType data
#' @format Eventlog containing 40  cases
#' @keywords datasets
#' @references Process Mining: Discovery, Conformance and Enhancement of Business Processes by W.M.P. van der Aalst, Springer Verlag, 2011 (ISBN 978-3-642-19344-6).
#' @source <http://www.processmining.org/event_logs_and_models_used_in_book>
"L_heur_1"

#' @name L_heur_2
#' @title Heuristics miner example log #2
#' @description Artifical eventlog for illustrating Heuristics Miner published as supplementary material to the book
#'  `Process Mining: Discovery, Conformance and Enhancement of Business Processes`.
#' @docType data
#' @format Eventlog containing 85 cases
#' @keywords datasets
#' @references Process Mining: Discovery, Conformance and Enhancement of Business Processes by W.M.P. van der Aalst, Springer Verlag, 2011 (ISBN 978-3-642-19344-6).
#' @source <http://www.processmining.org/event_logs_and_models_used_in_book>
"L_heur_2"

#' @name hospital_multi_perspective
#' @title Hospital example event log capturing multi-perspectives
#' @description Sample of 10000 traces from an artifical eventlog from the PhD thesis 'Multi-perspective Process Mining' used to illustrate the Data-aware Heuristic Miner algorithm.
#' @docType data
#' @format Eventlog containing a sample of 10000 cases
#' @keywords datasets
#' @references Mannhardt, F. (Felix) (2016) Data-driven Process Discovery - Artificial Event Log. Eindhoven University of Technology. Dataset. https://doi.org/10.4121/uuid:32cad43f-8bb9-46af-8333-48aae2bea037
#' @source <https://data.4tu.nl/repository/uuid:32cad43f-8bb9-46af-8333-48aae2bea037>
"hospital_multi_perspective"

==> heuristicsmineR_0.2.2.tar.gz: heuristicsmineR/R/datasets.R <==
#' @name L_heur_1
#' @title Heuristics miner example log #1
#' @description Artificial eventlog for illustrating Heuristics Miner published as supplementary material to the book
#'  `Process Mining: Discovery, Conformance and Enhancement of Business Processes`.
#' @docType data
#' @format Eventlog containing 40  cases
#' @keywords datasets
#' @references Process Mining: Discovery, Conformance and Enhancement of Business Processes by W.M.P. van der Aalst, Springer Verlag, 2011 (ISBN 978-3-642-19344-6).
#' @source <http://www.processmining.org/event_logs_and_models_used_in_book>
"L_heur_1"

#' @name L_heur_2
#' @title Heuristics miner example log #2
#' @description Artificial eventlog for illustrating Heuristics Miner published as supplementary material to the book
#'  `Process Mining: Discovery, Conformance and Enhancement of Business Processes`.
#' @docType data
#' @format Eventlog containing 85 cases
#' @keywords datasets
#' @references Process Mining: Discovery, Conformance and Enhancement of Business Processes by W.M.P. van der Aalst, Springer Verlag, 2011 (ISBN 978-3-642-19344-6).
#' @source <http://www.processmining.org/event_logs_and_models_used_in_book>
"L_heur_2"

#' @name hospital_multi_perspective
#' @title Hospital example event log capturing multi-perspectives
#' @description Sample of 10 000 traces from an artificial eventlog from the PhD thesis 'Multi-perspective Process Mining' used to illustrate the Data-aware Heuristic Miner algorithm.
#' @docType data
#' @format Eventlog containing a sample of 10 000 cases
#' @keywords datasets
#' @references Mannhardt, F. (Felix) (2016) Data-driven Process Discovery - Artificial Event Log. Eindhoven University of Technology. Dataset. https://doi.org/10.4121/uuid:32cad43f-8bb9-46af-8333-48aae2bea037
#' @source <https://data.4tu.nl/repository/uuid:32cad43f-8bb9-46af-8333-48aae2bea037>
"hospital_multi_perspective"
